// $Id: Global.java,v 1.4 2002/12/14 00:17:49 mike Exp $

package org.z3950.zoom;
import java.util.Hashtable;
import java.util.Properties;
import java.io.*;

/**
 * This class is merely a namespace for the non-class functions
 * described in the ZOOM Abstract API (<B>UNSTABLE</B>).
 * <P>
 * <B>THIS CLASS'S INTERFACE IS UNSTABLE PENDING DISCUSSION ON THE
 * ZOOM MAILING LIST.  DO NOT DEPEND ON IT.</B>
 *
 * @version	$Id: Global.java,v 1.4 2002/12/14 00:17:49 mike Exp $
 * @see	<A href="http://zoom.z3950.org/api/zoom-1.1.html#3.6"
 *		       >zoom.z3950.org/api/zoom-1.1.html#3.6</A>
 */
public class Global {
    private static final String Bib1File = "Bib1Diag.properties";
    private static Hashtable options = new Hashtable();
    private static Properties Bib1Diag = null;

    private Global() { /* Prevent instantiation */ }

    /**
     * Returns the value of the specified option in the global option
     * set.
     *
     * @param key	the name of the requested option
     * @return		the value of the specified option, or null if
     *			no such option has been defined.
     * @see	<A href="http://zoom.z3950.org/api/zoom-1.1.html#3.6.2"
     *		               >zoom.z3950.org/api/zoom-1.1.html#3.6.2</A>
     */
    public static String option(String key) {
	return (String) options.get(key);
    }

    /**
     * Sets the specified option in the global option set to the
     * specified value, returning its previous value (as would have
     * been returned by the single-parameter version.)
     *
     * @param key	the name of the option to set
     * @param value	the value to which to set the specified option
     * @return		the old value of the specified option, if any
     * @see	<A href="http://zoom.z3950.org/api/zoom-1.1.html#3.6.2"
     *		               >zoom.z3950.org/api/zoom-1.1.html#3.6.2</A>
     */
    public static String option(String key, String val) {
	String old = option(key);
	options.put(key, val);
	return old;
    }

    //      ###	This ought really to be done by invoking a similar
    //		function in JZkit, but unfortunately none seems to
    //		exist.  Perhaps this is because JZkit never seems to
    //		actually get hold of a BIB-1 diagnostic.
    /**
     * Maps the specified BIB-1 diagnostic code into a human-readable
     * message.  This is done by reference to a properties file,
     * <CODE>Bib1Diag.properties</CODE>, which may be edited or
     * replaced to yield diagnostic messages in a language other than
     * English.
     * <P>
     * The default properties file takes its text directly from Table
     * A-4-1: <I>Diagnostic Conditions</I>, in Appendix ERR.1
     * (<I>Diagnostic Set Bib-1</I>) of Z39.50-1995.  Upper/lower case
     * inconsistencies and all :-)
     *
     * @param code	The BIB-1 diagnostic code to be translated
     * @return		A corresponding human-readable message.
     * @see	<A href="http://lcweb.loc.gov/z3950/agency/defns/bib1diag.html"
     *			>Bib-1 Diagnostics in the Z39.50 standard</A>
     */
    public static String code2msg (int code) {
	if (Bib1Diag == null) {
	    try {
		InputStream is = Global.class.getResourceAsStream(Bib1File);
		if (is == null)
		    return "[can't getResourceAsStream(" + Bib1File + ")]";
		Bib1Diag = new Properties();
		Bib1Diag.load(is);
	    } catch (IOException ex) {
		return "[I/O exception on file '" + Bib1File + "']";
	    }
	}

	String msg = Bib1Diag.getProperty(Integer.toString(code));
	if (msg != null)
	    return msg;
	return "BIB-1 error #" + Integer.toString(code);
    }
}
